@@ -533,18 +533,13 @@ class matrix(numpy.matrix):
     # The NumPy doc for getI is empty:
     # @uncertainties.set_doc(numpy.matrix.getI.__doc__)
     def getI(self):
-        "Matrix inverse of pseudo-inverse"
+        "Matrix inverse or pseudo-inverse"
         
         # numpy.matrix.getI is OK too, but the rest of the code assumes that
         # numpy.matrix.I is a property object anyway:
 
-        M, N = self.shape
-        if M == N:
-            func = inv
-        else:
-            func = pinv
-        return func(self)
-        
+        m, n = self.shape
+        return (inv if m == n else pinv)(self)
 
     # ! In Python >= 2.6, this could be simplified as:
     # I = numpy.matrix.I.getter(__matrix_inverse)
@@ -595,6 +590,9 @@ def define_vectorized_funcs():
         for f_name in ['acos', 'acosh', 'asin', 'atan', 'atan2', 'atanh'])
 
     new_func_names = [func_name_translations.get(function_name, function_name)
+                      # The functions from umath.non_std_wrapped_funcs
+                      # (available from umath) are normally not in
+                      # numpy, so they are not included here:
                       for function_name in umath.many_scalars_to_scalar_funcs]
         
     for (function_name, unumpy_name) in zip(
